# pyspinnaker

[![Build Status][pyspinnaker-travis-image] ][pyspinnaker-travis-url]
[![License: MIT][pyspinnaker-license-image] ][pyspinnaker-license-url]

[pyspinnaker-travis-image]: https://travis-ci.org/jdewinne/pyspinnaker.svg?branch=master
[pyspinnaker-travis-url]: https://travis-ci.org/jdewinne/pyspinnaker
[pyspinnaker-license-image]: https://img.shields.io/badge/License-MIT-yellow.svg
[pyspinnaker-license-url]: https://opensource.org/licenses/MIT

A python implementation of the Spinnaker API
